#ifndef  __ADVANCED_API_H__
#define  __ADVANCED_API_H__


#include <Python.h>
#include <senna.h>


PyObject *senna_sen_sym_open(PyObject *self, PyObject *args, PyObject *keywds);
PyObject *senna_sen_sym_info(PyObject *self, PyObject *args, PyObject *keywds);
PyObject *senna_sen_sym_close(PyObject *self, PyObject *args, PyObject *keywds);
PyObject *senna_sen_sym_size(PyObject *self, PyObject *args, PyObject *keywds);
PyObject *senna_sen_sym_at(PyObject *self, PyObject *args, PyObject *keywds);
PyObject *senna_sen_sym_inspect(PyObject *self, PyObject *args, PyObject *keywds);
PyObject *senna_sen_sym_inspect_term(PyObject *self, PyObject *args, PyObject *keywds);

#endif  /* __ADVANCED_API_H__ */
